==> sodium-native-1.4.0.tgz: package/src/crypto_hash_sha512_wrap.cc <==
#include "crypto_hash_sha512_wrap.h"
#include "macros.h"

static Nan::Persistent<FunctionTemplate> crypto_hash_sha512_constructor;

CryptoHashSha512Wrap::CryptoHashSha512Wrap () {
  this->state = NULL;
}

CryptoHashSha512Wrap::~CryptoHashSha512Wrap () {
  sodium_free(this->state);
}

NAN_METHOD(CryptoHashSha512Wrap::New) {
  CryptoHashSha512Wrap* obj = new CryptoHashSha512Wrap();
  obj->Wrap(info.This());
  info.GetReturnValue().Set(info.This());
}

NAN_METHOD(CryptoHashSha512Wrap::Update) {
  CryptoHashSha512Wrap *self = Nan::ObjectWrap::Unwrap<CryptoHashSha512Wrap>(info.This());
  ASSERT_BUFFER_SET_LENGTH(info[0], input)
  crypto_hash_sha512_update(self->state, CDATA(input), input_length);
}

NAN_METHOD(CryptoHashSha512Wrap::Final) {
  CryptoHashSha512Wrap *self = Nan::ObjectWrap::Unwrap<CryptoHashSha512Wrap>(info.This());
  ASSERT_BUFFER_MIN_LENGTH(info[0], output, crypto_hash_sha512_BYTES)
  crypto_hash_sha512_final(self->state, CDATA(output));
}

void CryptoHashSha512Wrap::Init () {
  Local<FunctionTemplate> tpl = Nan::New<FunctionTemplate>(CryptoHashSha512Wrap::New);
  crypto_hash_sha512_constructor.Reset(tpl);
  tpl->SetClassName(Nan::New("CryptoHashSha512Wrap").ToLocalChecked());
  tpl->InstanceTemplate()->SetInternalFieldCount(1);

  Nan::SetPrototypeMethod(tpl, "update", CryptoHashSha512Wrap::Update);
  Nan::SetPrototypeMethod(tpl, "final", CryptoHashSha512Wrap::Final);
}

Local<Value> CryptoHashSha512Wrap::NewInstance () {
  Nan::EscapableHandleScope scope;

  Local<Object> instance;

  Local<FunctionTemplate> constructorHandle = Nan::New<FunctionTemplate>(crypto_hash_sha512_constructor);
  instance = Nan::NewInstance(constructorHandle->GetFunction()).ToLocalChecked();

  CryptoHashSha512Wrap *self = Nan::ObjectWrap::Unwrap<CryptoHashSha512Wrap>(instance);
  self->state = (crypto_hash_sha512_state*) sodium_malloc(crypto_hash_sha512_statebytes());
  crypto_hash_sha512_init(self->state);

  return scope.Escape(instance);
}

==> sodium-native-1.7.0.tgz: package/src/crypto_hash_sha512_wrap.cc <==
#include "crypto_hash_sha512_wrap.h"
#include "macros.h"

static Nan::Persistent<FunctionTemplate> crypto_hash_sha512_constructor;

CryptoHashSha512Wrap::CryptoHashSha512Wrap () {}

CryptoHashSha512Wrap::~CryptoHashSha512Wrap () {}

NAN_METHOD(CryptoHashSha512Wrap::New) {
  CryptoHashSha512Wrap* obj = new CryptoHashSha512Wrap();
  obj->Wrap(info.This());
  info.GetReturnValue().Set(info.This());
}

NAN_METHOD(CryptoHashSha512Wrap::Update) {
  CryptoHashSha512Wrap *self = Nan::ObjectWrap::Unwrap<CryptoHashSha512Wrap>(info.This());
  ASSERT_BUFFER_SET_LENGTH(info[0], input)
  crypto_hash_sha512_update(&(self->state), CDATA(input), input_length);
}

NAN_METHOD(CryptoHashSha512Wrap::Final) {
  CryptoHashSha512Wrap *self = Nan::ObjectWrap::Unwrap<CryptoHashSha512Wrap>(info.This());
  ASSERT_BUFFER_MIN_LENGTH(info[0], output, crypto_hash_sha512_BYTES)
  crypto_hash_sha512_final(&(self->state), CDATA(output));
}

void CryptoHashSha512Wrap::Init () {
  Local<FunctionTemplate> tpl = Nan::New<FunctionTemplate>(CryptoHashSha512Wrap::New);
  crypto_hash_sha512_constructor.Reset(tpl);
  tpl->SetClassName(Nan::New("CryptoHashSha512Wrap").ToLocalChecked());
  tpl->InstanceTemplate()->SetInternalFieldCount(1);

  Nan::SetPrototypeMethod(tpl, "update", CryptoHashSha512Wrap::Update);
  Nan::SetPrototypeMethod(tpl, "final", CryptoHashSha512Wrap::Final);
}

Local<Value> CryptoHashSha512Wrap::NewInstance () {
  Nan::EscapableHandleScope scope;

  Local<Object> instance;

  Local<FunctionTemplate> constructorHandle = Nan::New<FunctionTemplate>(crypto_hash_sha512_constructor);
  instance = Nan::NewInstance(constructorHandle->GetFunction()).ToLocalChecked();

  CryptoHashSha512Wrap *self = Nan::ObjectWrap::Unwrap<CryptoHashSha512Wrap>(instance);
  crypto_hash_sha512_init(&(self->state));

  return scope.Escape(instance);
}
